package org.klomp.eclipse.team.sftp.target;

import java.io.ByteArrayInputStream;
import java.io.InputStream;
import java.net.MalformedURLException;
import java.net.URL;

import org.eclipse.core.resources.IStorage;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IPath;
import org.eclipse.core.runtime.Path;

import org.eclipse.team.core.TeamException;
import org.klomp.eclipse.team.sftp.SftpPlugin;

/**
 * Used for type-determination purposes.
 */
class RemoteDisconnectedStorage implements IStorage
{
    private final static byte[] NO_BYTES = new byte[0];

    private URL providerURL;
    private IPath providerRelativePath;

    public RemoteDisconnectedStorage(URL providerURL, IPath providerRelativePath)
    {
        this.providerURL = providerURL;
        this.providerRelativePath = providerRelativePath;
    }

    public InputStream getContents() throws CoreException
    {
        // Not connecting to remote resource; pretend file is empty for type determination purposes.
        return new ByteArrayInputStream(NO_BYTES);
    }

    public IPath getFullPath()
    {
        return new Path(getURL().getPath());
    }

    public String getName()
    {
        if (providerRelativePath.isEmpty() || providerRelativePath.isRoot())
        {
            return providerURL.toExternalForm();
        }
        return providerRelativePath.lastSegment();
    }

    private URL getURL()
    {
        try
        {
            return new URL(providerURL, providerRelativePath.toString());
        }
        catch (MalformedURLException e)
        {
            SftpPlugin.log(new TeamException(SftpPlugin.getString("%SftpRemoteTargetResource.invalidURL"), e)); //$NON-NLS-1$
            return null;
        }
    }

    public boolean isReadOnly()
    {
        return true;
    }

    public Object getAdapter(Class adapter)
    {
        return null;
    }

}
