package org.klomp.eclipse.team.sftp.util;

import java.io.InputStream;

import org.eclipse.core.runtime.IProgressMonitor;

import org.eclipse.team.internal.core.streams.ProgressMonitorInputStream;
import org.klomp.eclipse.team.sftp.SftpPlugin;

public class SftpProgressInputStream extends ProgressMonitorInputStream
{
    private String title;
    private long previousBytesRead = 0;
    private long previousChangeTitle = 0;

    public SftpProgressInputStream(InputStream in, long fileSize, String title, IProgressMonitor monitor)
    {
        super(in, fileSize, SftpPlugin.TRANSFER_PROGRESS_INCREMENT, monitor);
        this.title = title;
    }

    protected void updateMonitor(long bytesRead, long bytesTotal, IProgressMonitor monitor)
    {
        if (bytesRead == 0)
        {
            return;
        }
        long worked = bytesRead - previousBytesRead;
        previousBytesRead = bytesRead;
        monitor.worked((int) worked);

        if (bytesRead - previousChangeTitle > (bytesTotal / SftpPlugin.TRANSFER_PROGRESS_TITLE_STEPS))
        {
            previousChangeTitle = bytesRead;
            monitor.subTask(
                SftpPlugin.formatResourceString(
                    "%SftpClient.transferSize",
                    new String[] { title, Long.toString(bytesRead >> 10), Long.toString(bytesTotal >> 10)}));
        }
    }
}
