package org.klomp.sftp.packet;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

import org.klomp.ssh.DataIO;

public class FxpName extends SftpPacket
{
    private List fileNames = new ArrayList();
    private Map longNames = new HashMap();
    private Map attrs = new HashMap();

    FxpName(int version)
    {
        super(SftpPacket.FXP_NAME, version);
    }

    FxpName(int version, int id)
    {
        super(SftpPacket.FXP_NAME, version, id);
    }

    protected void readPayload(InputStream payload) throws IOException
    {
        id = DataIO.readInt(payload);
        int count = DataIO.readInt(payload);
        for (int i = 0; i < count; i++)
        {
            String fileName = DataIO.readStringUTF8(payload);
            if (version <= 3)
            {
                String longName = DataIO.readStringUTF8(payload);
                longNames.put(fileName, longName);
            }
            Attrs a = new Attrs();
            a.readAttrs(payload, version);
            fileNames.add(fileName);
            attrs.put(fileName, a);

        }
    }

    protected void writePayload(ByteArrayOutputStream payload)
    {
        DataIO.writeInt(payload, id);
        DataIO.writeInt(payload, fileNames.size());
        for (Iterator i = fileNames.iterator(); i.hasNext();)
        {
            String fileName = (String) i.next();
            if (version <= 3)
            {
                String longName = getLongName(fileName);
                if (longName == null)
                    longName = fileName;
                DataIO.writeStringUTF8(payload, longName);
            }
            Attrs a = (Attrs) attrs.get(fileName);
            DataIO.writeStringUTF8(payload, fileName);
            a.writeAttrs(payload, version);
        }
    }

    public void addFile(String fileName, Attrs a)
    {
        fileNames.add(fileName);
        attrs.put(fileName, a);
    }

    public List getFiles()
    {
        return Collections.unmodifiableList(fileNames);
    }

    public Attrs getAttrs(String fileName)
    {
        return (Attrs) attrs.get(fileName);
    }

    public String getLongName(String fileName)
    {
        return (String) longNames.get(fileName);
    }

    public Map getAttrs()
    {
        return Collections.unmodifiableMap(attrs);
    }
}