package org.klomp.sftp.packet;

import java.io.ByteArrayOutputStream;
import java.io.EOFException;
import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

import org.klomp.ssh.DataIO;

public class FxpVersion extends SftpPacket
{
    private int version;
    private List extensionNames = new ArrayList();
    private Map extensions = new HashMap();

    FxpVersion(int version)
    {
        super(SftpPacket.FXP_VERSION, version);
    }

    protected void readPayload(InputStream payload) throws IOException
    {
        version = DataIO.readInt(payload);
        while (true)
        {
            try
            {
                String extensionName = DataIO.readStringUTF8(payload);
                String extensionData = DataIO.readStringUTF8(payload);
                extensionNames.add(extensionName);
                extensions.put(extensionName, extensionData);
            }
            catch (EOFException e)
            {
                break;
            }
        }
    }

    protected void writePayload(ByteArrayOutputStream payload)
    {
        DataIO.writeInt(payload, version);
        for (Iterator i = extensionNames.iterator(); i.hasNext();)
        {
            String extensionName = (String) i.next();
            DataIO.writeStringUTF8(payload, extensionName);
            DataIO.writeStringUTF8(payload, (String) extensions.get(extensionName));
        }
    }
    public int getVersion()
    {
        return version;
    }

    public void setVersion(int version)
    {
        this.version = version;
    }

}