package org.klomp.sftp.protocol;

import java.util.Map;

import org.eclipse.core.runtime.IProgressMonitor;

import org.klomp.eclipse.team.sftp.SftpException;
import org.klomp.eclipse.team.sftp.SftpPlugin;
import org.klomp.sftp.packet.Attrs;
import org.klomp.sftp.packet.FxpMkDir;
import org.klomp.sftp.packet.FxpRmDir;
import org.klomp.sftp.packet.FxpStatus;

public class Directories extends Operations {
    public Directories(SftpConnection connection) {
        super(connection);
    }

    /**
     * Deletes a remote directory.
     * @param directoryPath the absolute or relative path of the directory
     * @param monitor the progress monitor, or null
     */
    public void deleteDirectory(String directoryPath, IProgressMonitor monitor)
        throws SftpException {

        monitor = SftpPlugin.monitorFor(monitor);
        monitor.beginTask(null, 100);
        monitor.subTask(SftpPlugin.formatResourceString("%SftpClient.deleteDirectory", directoryPath)); //$NON-NLS-1$

        try {
            FxpRmDir pkt = pktFactory.createRmDir();
            pkt.setPath(directoryPath);
            connection.sendPacket(pkt);
            FxpStatus status = readStatus(pkt.getId());
            defaultStatusHandler(status);
            monitor.worked(50);
        } finally {
            monitor.done();
        }
    }

    /**
     * Creates a remote directory.
     * @param directoryPath the absolute or relative path of the directory
     * @param monitor the progress monitor, or null
     */
    public void createDirectory(String directoryPath, IProgressMonitor monitor)
        throws SftpException {

        monitor = SftpPlugin.monitorFor(monitor);
        monitor.beginTask(null, 100);
        monitor.subTask(SftpPlugin.formatResourceString("%SftpClient.createDirectory", directoryPath)); //$NON-NLS-1$

        try {
            FxpMkDir pkt = pktFactory.createMkDir();
            pkt.setPath(directoryPath);
            Attrs attrs = new Attrs();

            pkt.setAttrs(attrs);
            connection.sendPacket(pkt);
            FxpStatus status = readStatus(pkt.getId());
            defaultStatusHandler(status);
            monitor.worked(50);
        } finally {
            monitor.done();
        }
    }

    public Map retrieveDirectory(String directoryPath, IProgressMonitor monitor)
        throws SftpException {

        monitor = SftpPlugin.monitorFor(monitor);
        monitor.beginTask(null, 100);
        monitor.subTask(SftpPlugin.formatResourceString("%SftpClient.retrieveDirectory", directoryPath)); //$NON-NLS-1$
        try {
            Map attrs;

            DirectoryFile directory = DirectoryFile.openDir(connection, directoryPath);
            try {
                attrs = directory.list(monitor);
            } finally {
                directory.close();
            }
            return attrs;
        } finally {
            monitor.done();
        }
    }
}
